@@ -28,9 +28,6 @@
 /* Clp support */
 /* #undef HAVE_CLP */
 
-/* Cocoa API */
-/* #undef HAVE_COCOA */
-
 /* NVIDIA CUDA Runtime API*/
 /* #undef HAVE_CUDA */
 
@@ -56,12 +53,6 @@
 /* Geospatial Data Abstraction Library */
 /* #undef HAVE_GDAL */
 
-/* GTK+ 2.0 Thread support */
-#define HAVE_GTHREAD
-
-/* GTK+ 2.x toolkit */
-#define HAVE_GTK
-
 /* Halide support */
 /* #undef HAVE_HALIDE */
 
@@ -121,12 +112,6 @@
 /* parallel_for with pthreads */
 #define HAVE_PTHREADS_PF
 
-/* Qt support */
-/* #undef HAVE_QT */
-
-/* Qt OpenGL support */
-/* #undef HAVE_QT_OPENGL */
-
 /* Intel Threading Building Blocks */
 /* #undef HAVE_TBB */
 
@@ -136,12 +121,9 @@
 /* TIFF codec */
 #define HAVE_TIFF
 
-/* Win32 UI */
-/* #undef HAVE_WIN32UI */
-
 /* Define if your processor stores words with the most significant byte
    first (like Motorola and SPARC, unlike Intel and VAX). */
-#define WORDS_BIGENDIAN
+/* #undef WORDS_BIGENDIAN */
 
 /* VA library (libva) */
 /* #undef HAVE_VA */
